[e-cvs] cvs commit: e/src/jsrc/org/erights/e/ui/jed EAction.java EMenuBar.java

markm@eros.cs.jhu.edu markm@eros.cs.jhu.edu
Tue, 2 Oct 2001 19:38:33 -0400


markm       01/10/02 19:38:32

  Modified:    src/jsrc/net/vattp/data Msg.java StartUpProtocol.java
                        VatIdentity.java
               src/jsrc/org/apache/oro/text/regex CharStringPointer.java
                        OpCode.java Perl5Compiler.java Perl5Debug.java
                        Perl5Matcher.java Perl5Pattern.java
                        Perl5Substitution.java Util.java
               src/jsrc/org/erights/e/develop/trace Trace.java
                        TraceController.java TraceLog.java
                        TraceLogDescriptor.java
               src/jsrc/org/erights/e/elib/base ClassDesc.java
               src/jsrc/org/erights/e/elib/prim BERunner.java
                        SacrificialComponent.java ScriptMaker.java
                        StaticMaker.java
               src/jsrc/org/erights/e/elib/prim/tests ERunDemo.java
               src/jsrc/org/erights/e/elib/ref DeviceRef.java Ref.java
                        StemCell.java WhenBrokenReactor.java
                        WhenResolvedReactor.java
               src/jsrc/org/erights/e/elib/serial PassByConstruction.java
                        PassByProxy.java Persistent.java RemoteCall.java
                        RemoteDelivery.java
               src/jsrc/org/erights/e/elib/tables ConstMap.java
                        ConstMapImpl.java EMap.java EmptyTwine.java
                        Equalizer.java KeyColumn.java Selfless.java
               src/jsrc/org/erights/e/extern/timer Timer.java
               src/jsrc/org/erights/e/meta/java/lang ArrayGuardSugar.java
                        InterfaceGuardSugar.java
               src/jsrc/org/erights/e/ui/jed EAction.java EMenuBar.java
  Log:
  fixed some code convention errors

Revision  Changes    Path
1.5       +5 -5      e/src/jsrc/net/vattp/data/Msg.java

Index: Msg.java
===================================================================
RCS file: /cvs/e/src/jsrc/net/vattp/data/Msg.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- Msg.java	2001/10/02 01:29:18	1.4
+++ Msg.java	2001/10/02 23:38:31	1.5
@@ -22,10 +22,10 @@
 
 /**
  * Define the allowable message types for the VatTP system.
- * This class only contains static final values.  It can not be
+ * This class only contains static private final values.  It can not be
  * instantiated.
  *
- * <p>This class only defines static final values.
+ * <p>This class only defines static private final values.
  * @author Bill Frantz
  */
 public class Msg {
@@ -60,10 +60,10 @@
     static /*package*/ final byte PONG              = 6;
 
     /** E level message to an object at the remote end */
-    public      static final byte E_MSG             = 7;
+    static      public final byte E_MSG             = 7;
 
     /** RMI Comm message to a stream at the other end */
-    public      static final byte TUNNEL_MSG        = 8;
+    static      public final byte TUNNEL_MSG        = 8;
 
     // We want to fill in here with other message codes to keep the allocation
     // compact.
@@ -105,5 +105,5 @@
      * time after we have sent a ping, we declare the connection down.
      * In milliseconds.*/
     static /*package*/ final long PING_TIMEOUT = 20*1000*TIME_FUDGE;
-    private Msg() {}    // This class is only static final values.
+    private Msg() {}    // This class is only static private final values.
 }



1.7       +2 -2      e/src/jsrc/net/vattp/data/StartUpProtocol.java

Index: StartUpProtocol.java
===================================================================
RCS file: /cvs/e/src/jsrc/net/vattp/data/StartUpProtocol.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- StartUpProtocol.java	2001/10/02 01:49:35	1.6
+++ StartUpProtocol.java	2001/10/02 23:38:31	1.7
@@ -241,8 +241,8 @@
 
     // Data for the Diffie Hellman protocol
     BigInteger x = null;
-    static final BigInteger g = new BigInteger("2");
-    static final BigInteger modulus =
+    static private final BigInteger g = new BigInteger("2");
+    static private final BigInteger modulus =
         new BigInteger("11973791477546250983817043765044391637751157152328012"
                         + "72278994477192940843207042535379780702841268263028"
                         + "59486033998465467188646855777933154987304015680716"



1.6       +1 -1      e/src/jsrc/net/vattp/data/VatIdentity.java

Index: VatIdentity.java
===================================================================
RCS file: /cvs/e/src/jsrc/net/vattp/data/VatIdentity.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- VatIdentity.java	2001/09/06 09:55:39	1.5
+++ VatIdentity.java	2001/10/02 23:38:31	1.6
@@ -42,7 +42,7 @@
 
     /** VatID to use for connecting to unknown vats at a specific IP
      * address */
-    static /*package*/ String WHOEVER = "0";
+    static /*package*/ final String WHOEVER = "0";
 
     /** prevent instantiation */
     private VatIdentity() {}



1.4       +2 -2      e/src/jsrc/org/apache/oro/text/regex/CharStringPointer.java

Index: CharStringPointer.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/CharStringPointer.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- CharStringPointer.java	2001/09/06 09:55:41	1.3
+++ CharStringPointer.java	2001/10/02 23:38:31	1.4
@@ -63,11 +63,11 @@
  * It is expected that the compiler will inline all the functions.
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: CharStringPointer.java,v 1.3 2001/09/06 09:55:41 markm Exp $
+ @version $Id: CharStringPointer.java,v 1.4 2001/10/02 23:38:31 markm Exp $
 
 */
 final class CharStringPointer {
-    static final char _END_OF_STRING = Character.MAX_VALUE;
+    static /*package*/ final char _END_OF_STRING = Character.MAX_VALUE;
     int _offset;
     char[] _array;
 



1.4       +17 -17    e/src/jsrc/org/apache/oro/text/regex/OpCode.java

Index: OpCode.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/OpCode.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- OpCode.java	2001/09/06 09:55:41	1.3
+++ OpCode.java	2001/10/02 23:38:31	1.4
@@ -63,7 +63,7 @@
  * op-codes used in a compiled regular expression.
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: OpCode.java,v 1.3 2001/09/06 09:55:41 markm Exp $
+ @version $Id: OpCode.java,v 1.4 2001/10/02 23:38:31 markm Exp $
 */
 final class OpCode {
 
@@ -72,7 +72,7 @@
     // Names, values, and descriptions of operators correspond to those of
     // Perl regex bytecodes and for compatibility purposes are drawn from
     // regcomp.h in the Perl source tree by Larry Wall.
-    static final char  // Has Operand   Meaning
+    static /*package*/ final char  // Has Operand   Meaning
         _END     = 0,   // no       End of program.
         _BOL     = 1,   // no       Match "" at beginning of line.
         _MBOL    = 2,   // no       Same, assuming multiline.
@@ -110,56 +110,56 @@
         _WHILEM  = 34;  // no       Do curly processing and see if rest matches.
 
     // Lengths of the various operands.
-    static final int _operandLength[] = {
+    static /*package*/ final int _operandLength[] = {
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0,
         0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0
     };
 
-    static final char _opType[] = {
+    static /*package*/ final char _opType[] = {
         _END, _BOL, _BOL, _BOL, _EOL, _EOL, _EOL, _ANY, _ANY, _ANYOF, _CURLY,
         _CURLY, _BRANCH, _BACK, _EXACTLY, _NOTHING, _STAR, _PLUS, _ALNUM,
         _NALNUM, _BOUND, _NBOUND, _SPACE, _NSPACE, _DIGIT, _NDIGIT, _REF,
         _OPEN, _CLOSE, _MINMOD, _BOL, _BRANCH, _BRANCH, _END, _WHILEM
     };
 
-    static final char _opLengthVaries[] = {
+    static /*package*/ final char _opLengthVaries[] = {
         _BRANCH, _BACK, _STAR, _PLUS, _CURLY, _CURLYX, _REF, _WHILEM
     };
 
-    static final char _opLengthOne[] = {
+    static /*package*/ final char _opLengthOne[] = {
         _ANY, _SANY, _ANYOF, _ALNUM, _NALNUM, _SPACE, _NSPACE, _DIGIT, _NDIGIT
     };
 
-    static final int  _NULL_OFFSET  = -1;
-    static final char _NULL_POINTER =  0;
+    static /*package*/ final int  _NULL_OFFSET  = -1;
+    static /*package*/ final char _NULL_POINTER =  0;
 
-    static final int _getNextOffset(char[] program, int offset) {
+    static private final int _getNextOffset(char[] program, int offset) {
         return ((int)program[offset + 1]);
     }
 
-    static final char _getArg1(char[] program, int offset) {
+    static /*package*/ final char _getArg1(char[] program, int offset) {
         return program[offset + 2];
     }
 
-    static final char _getArg2(char[] program, int offset) {
+    static /*package*/ final char _getArg2(char[] program, int offset) {
         return program[offset + 3];
     }
 
-    static final int _getOperand(int offset) {
+    static /*package*/ final int _getOperand(int offset) {
         return (offset + 2);
     }
 
-    static final boolean _isInArray(char ch, char[] array, int start) {
+    static /*package*/ final boolean _isInArray(char ch, char[] array, int start) {
         while(start < array.length)
             if(ch == array[start++])
                 return true;
         return false;
     }
 
-    static final int _getNextOperator(int offset) { return (offset + 2); }
-    static final int _getPrevOperator(int offset) { return (offset - 2); }
+    static /*package*/ final int _getNextOperator(int offset) { return (offset + 2); }
+    static /*package*/ final int _getPrevOperator(int offset) { return (offset - 2); }
 
-    static final int _getNext(char[] program, int offset) {
+    static /*package*/ final int _getNext(char[] program, int offset) {
         int offs;
 
         if(program == null)
@@ -178,7 +178,7 @@
 
     // doesn't really belong in this class, but we want Perl5Matcher not to
     // depend on Perl5Compiler
-    static final boolean _isWordCharacter(char token) {
+    static /*package*/ final boolean _isWordCharacter(char token) {
         return ((token >= 'a' && token <= 'z') ||
                 (token >= 'A' && token <= 'Z') ||
                 (token >= '0' && token <= '9') ||



1.4       +19 -19    e/src/jsrc/org/apache/oro/text/regex/Perl5Compiler.java

Index: Perl5Compiler.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/Perl5Compiler.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- Perl5Compiler.java	2001/09/06 09:55:41	1.3
+++ Perl5Compiler.java	2001/10/02 23:38:31	1.4
@@ -65,7 +65,7 @@
  * information about Perl5 regular expressions.
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: Perl5Compiler.java,v 1.3 2001/09/06 09:55:41 markm Exp $
+ @version $Id: Perl5Compiler.java,v 1.4 2001/10/02 23:38:31 markm Exp $
 
  * @see PatternCompiler
  * @see MalformedPatternException
@@ -74,10 +74,10 @@
  */
 
 public final class Perl5Compiler implements PatternCompiler {
-    private static final int __WORSTCASE = 0, __NONNULL = 0x1, __SIMPLE = 0x2,
+    static private final int __WORSTCASE = 0, __NONNULL = 0x1, __SIMPLE = 0x2,
         __SPSTART = 0x4, __TRYAGAIN = 0x8;
 
-    private static final char
+    static private final char
         __CASE_INSENSITIVE = 0x0001,
         __GLOBAL           = 0x0002,
         __KEEP             = 0x0004,
@@ -86,8 +86,8 @@
         __EXTENDED         = 0x0020,
         __READ_ONLY        = 0x8000;
 
-    private static final String __META_CHARS = "^$.[()|?+*\\";
-    private static final String __HEX_DIGIT =
+    static private final String __META_CHARS = "^$.[()|?+*\\";
+    static private final String __HEX_DIGIT =
         "0123456789abcdef0123456789ABCDEFx";
     private CharStringPointer __input;
     private boolean __sawBackreference;
@@ -118,13 +118,13 @@
      * will ALWAYS override whatever behavior is specified by the setMultiline()
      * in Perl5Matcher.
      */
-    public static final int DEFAULT_MASK          = 0;
+    static public final int DEFAULT_MASK          = 0;
 
     /**
      * A mask passed as an option to the {@link #compile compile} methods
      * to indicate a compiled regular expression should be case insensitive.
      */
-    public static final int CASE_INSENSITIVE_MASK = __CASE_INSENSITIVE;
+    static public final int CASE_INSENSITIVE_MASK = __CASE_INSENSITIVE;
 
     /**
      * A mask passed as an option to the  {@link #compile compile} methods
@@ -139,7 +139,7 @@
      * The <b>SINGLELINE_MASK</b> and <b>MULTILINE_MASK</b> should not be
      * used together.
      */
-    public static final int MULTILINE_MASK        = __MULTILINE;
+    static public final int MULTILINE_MASK        = __MULTILINE;
 
     /**
      * A mask passed as an option to the {@link #compile compile} methods
@@ -156,7 +156,7 @@
      * The <b>SINGLELINE_MASK</b> and <b>MULTILINE_MASK</b> should not be
      * used together.
      */
-    public static final int SINGLELINE_MASK       = __SINGLELINE;
+    static public final int SINGLELINE_MASK       = __SINGLELINE;
 
     /**
      * A mask passed as an option to the {@link #compile compile} methods
@@ -172,7 +172,7 @@
      * with Perl5 regular expressions, although it will not often
      * make sense to use it in Java.
      */
-    public static final int EXTENDED_MASK         = __EXTENDED;
+    static public final int EXTENDED_MASK         = __EXTENDED;
 
     /**
      * A mask passed as an option to the {@link #compile compile} methods
@@ -186,7 +186,7 @@
      * when you want to share a Perl5Pattern instance among multiple threads
      * using different Perl5Matcher instances.
      */
-    public static final int READ_ONLY_MASK        = __READ_ONLY;
+    static public final int READ_ONLY_MASK        = __READ_ONLY;
 
     /**
      * Given a character string, returns a Perl5 expression that interprets
@@ -202,7 +202,7 @@
      * @return A String containing a Perl5 regular expression corresponding to
      *         a literal interpretation of the pattern.
      */
-    public static final String quotemeta(char[] expression) {
+    static public final String quotemeta(char[] expression) {
         int ch;
         StringBuffer buffer;
 
@@ -230,15 +230,15 @@
      * @return A String containing a Perl5 regular expression corresponding to
      *         a literal interpretation of the pattern.
      */
-    public static final String quotemeta(String expression) {
+    static public final String quotemeta(String expression) {
         return quotemeta(expression.toCharArray());
     }
 
-    private static boolean __isSimpleRepetitionOp(char ch) {
+    static private boolean __isSimpleRepetitionOp(char ch) {
         return (ch == '*' || ch == '+' || ch == '?');
     }
 
-    private static boolean __isComplexRepetitionOp(char[] ch, int offset) {
+    static private boolean __isComplexRepetitionOp(char[] ch, int offset) {
         if(offset < ch.length && offset >= 0)
             return (ch[offset] == '*' || ch[offset] == '+' || ch[offset] == '?'
                     || (ch[offset] == '{' && __parseRepetition(ch, offset)));
@@ -246,7 +246,7 @@
     }
 
     // determines if {\d+,\d*} is the next part of the string
-    private static boolean __parseRepetition(char[] str, int offset) {
+    static private boolean __parseRepetition(char[] str, int offset) {
         if(str[offset] != '{')
             return false;
         ++offset;
@@ -269,7 +269,7 @@
         return true;
     }
 
-    private static int __parseHex(char[] str, int offset, int maxLength,
+    static private int __parseHex(char[] str, int offset, int maxLength,
                                   int[] scanned)
     {
         int val = 0, index;
@@ -286,7 +286,7 @@
         return val;
     }
 
-    private static int __parseOctal(char[] str, int offset, int maxLength,
+    static private int __parseOctal(char[] str, int offset, int maxLength,
                                     int[] scanned)
     {
         int val = 0, index;
@@ -304,7 +304,7 @@
         return val;
     }
 
-    private static void __setModifierFlag(char[] flags, char ch) {
+    static private void __setModifierFlag(char[] flags, char ch) {
         switch(ch) {
         case 'i' : flags[0] |= __CASE_INSENSITIVE; return;
         case 'g' : flags[0] |= __GLOBAL; return;



1.4       +2 -2      e/src/jsrc/org/apache/oro/text/regex/Perl5Debug.java

Index: Perl5Debug.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/Perl5Debug.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- Perl5Debug.java	2001/09/06 09:55:41	1.3
+++ Perl5Debug.java	2001/10/02 23:38:31	1.4
@@ -68,7 +68,7 @@
  * comparison with the program generated by Perl5 with the -r option.
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: Perl5Debug.java,v 1.3 2001/09/06 09:55:41 markm Exp $
+ @version $Id: Perl5Debug.java,v 1.4 2001/10/02 23:38:31 markm Exp $
 
  * @see Perl5Pattern
  */
@@ -98,7 +98,7 @@
      */
 
 
-    public static String printProgram(Perl5Pattern regexp) {
+    static public String printProgram(Perl5Pattern regexp) {
         StringBuffer buffer;
         char operator = OpCode._OPEN, prog[];
         int offset, next;



1.5       +6 -6      e/src/jsrc/org/apache/oro/text/regex/Perl5Matcher.java

Index: Perl5Matcher.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/Perl5Matcher.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- Perl5Matcher.java	2001/09/06 09:55:41	1.4
+++ Perl5Matcher.java	2001/10/02 23:38:31	1.5
@@ -65,14 +65,14 @@
  * Perl5Compiler.
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: Perl5Matcher.java,v 1.4 2001/09/06 09:55:41 markm Exp $
+ @version $Id: Perl5Matcher.java,v 1.5 2001/10/02 23:38:31 markm Exp $
 
  * @see PatternMatcher
  * @see Perl5Compiler
  */
 public final class Perl5Matcher implements PatternMatcher {
-    private static final char __EOS = Character.MAX_VALUE;
-    private static final int __INITIAL_NUM_OFFSETS = 20;
+    static private final char __EOS = Character.MAX_VALUE;
+    static private final int __INITIAL_NUM_OFFSETS = 20;
 
     private boolean __multiline = false, __lastSuccess = false;
     private char __previousChar, __input[], __originalInput[];
@@ -85,7 +85,7 @@
     private Stack __stack = new Stack();
     private Perl5MatchResult __lastMatchResult = null;
 
-    private static boolean
+    static private boolean
         __compare(char[] s1, int s1Offs, char[] s2, int s2Offs, int n)
     {
         int cnt;
@@ -102,7 +102,7 @@
         return true;
     }
 
-    private static int __findFirst(char[] input, int current, int endOffset,
+    static private int __findFirst(char[] input, int current, int endOffset,
                                    char[] mustString)
     {
         int count, saveCurrent;
@@ -1608,7 +1608,7 @@
     }
 
 
-    private static final int __DEFAULT_LAST_MATCH_END_OFFSET = -100;
+    static private final int __DEFAULT_LAST_MATCH_END_OFFSET = -100;
     private int __lastMatchInputEndOffset = __DEFAULT_LAST_MATCH_END_OFFSET;
     /**
      * Determines if the contents of a PatternMatcherInput, starting from the



1.3       +2 -2      e/src/jsrc/org/apache/oro/text/regex/Perl5Pattern.java

Index: Perl5Pattern.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/Perl5Pattern.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- Perl5Pattern.java	2001/09/06 09:55:41	1.2
+++ Perl5Pattern.java	2001/10/02 23:38:31	1.3
@@ -73,13 +73,13 @@
  * saved to disk if desired.
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: Perl5Pattern.java,v 1.2 2001/09/06 09:55:41 markm Exp $
+ @version $Id: Perl5Pattern.java,v 1.3 2001/10/02 23:38:31 markm Exp $
 
  * @see Perl5Compiler
  * @see Perl5Matcher
  */
 public final class Perl5Pattern implements Pattern, Serializable, Cloneable {
-  static final int _OPT_ANCH = 1, _OPT_SKIP = 2, _OPT_IMPLICIT = 4;
+  static /*package*/ final int _OPT_ANCH = 1, _OPT_SKIP = 2, _OPT_IMPLICIT = 4;
 
   String _expression;
   char[] _program;



1.4       +3 -3      e/src/jsrc/org/apache/oro/text/regex/Perl5Substitution.java

Index: Perl5Substitution.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/Perl5Substitution.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- Perl5Substitution.java	2001/09/06 09:55:41	1.3
+++ Perl5Substitution.java	2001/10/02 23:38:31	1.4
@@ -112,7 +112,7 @@
  * Also, <b>$0</b> is always interpreted literally.
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: Perl5Substitution.java,v 1.3 2001/09/06 09:55:41 markm Exp $
+ @version $Id: Perl5Substitution.java,v 1.4 2001/10/02 23:38:31 markm Exp $
 
  * @see Substitution
  * @see Util
@@ -126,14 +126,14 @@
      * interpolation variables should be computed relative to the most
      * recent pattern match.
      */
-    public static final int INTERPOLATE_ALL = 0;
+    static public final int INTERPOLATE_ALL = 0;
 
     /**
      * A constant used when creating a Perl5Substitution indicating that
      * interpolation variables should be interpreted literally, effectively
      * disabling interpolation.
      */
-    public static final int INTERPOLATE_NONE = -1;
+    static public final int INTERPOLATE_NONE = -1;
 
     int _numInterpolations;
     Vector _substitutions;



1.4       +7 -7      e/src/jsrc/org/apache/oro/text/regex/Util.java

Index: Util.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/apache/oro/text/regex/Util.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- Util.java	2001/09/06 09:55:41	1.3
+++ Util.java	2001/10/02 23:38:31	1.4
@@ -85,7 +85,7 @@
  * </ol>
 
  @author <a href="mailto:dfs@savarese.org">Daniel F. Savarese</a>
- @version $Id: Util.java,v 1.3 2001/09/06 09:55:41 markm Exp $
+ @version $Id: Util.java,v 1.4 2001/10/02 23:38:31 markm Exp $
 
  * @see Pattern
  * @see PatternMatcher
@@ -96,14 +96,14 @@
      * methods indicating that all occurrences of a pattern should be
      * substituted.
      */
-    public static final int SUBSTITUTE_ALL = -1;
+    static public final int SUBSTITUTE_ALL = -1;
 
     /**
      * A constant passed to the {@link #split split()} methods
      * indicating that all occurrences of a pattern should be used to
      * split a string.
      */
-    public static final int SPLIT_ALL = 0;
+    static public final int SPLIT_ALL = 0;
 
     /**
      * The default destructor for the Util class.  It is made private
@@ -154,7 +154,7 @@
      *         only the first <code>limit - 1</code> matches of the delimiting
      *         regular expression will be used to split the input.
      */
-    public static Vector split(PatternMatcher matcher, Pattern pattern,
+    static public Vector split(PatternMatcher matcher, Pattern pattern,
                                String input, int limit)
     {
         int beginOffset;
@@ -210,7 +210,7 @@
      * @return A <code>Vector</code> containing all the substrings of the input
      *         that occur between the regular expression delimiter occurences.
      */
-    public static Vector split( PatternMatcher matcher, Pattern pattern,
+    static public Vector split( PatternMatcher matcher, Pattern pattern,
                                 String input)
     {
         return split(matcher, pattern, input, SPLIT_ALL);
@@ -238,7 +238,7 @@
      *         if any, made.  If no substitutions are made, the returned String
      *         is the original input String.
      */
-    public static String substitute(PatternMatcher matcher, Pattern pattern,
+    static public String substitute(PatternMatcher matcher, Pattern pattern,
                                     Substitution sub, String input, int numSubs)
     {
         int beginOffset, subCount;
@@ -291,7 +291,7 @@
      *         if any, made.  If no substitutions are made, the returned String
      *         is the original input String.
      */
-    public static String substitute(PatternMatcher matcher, Pattern pattern,
+    static public String substitute(PatternMatcher matcher, Pattern pattern,
                                     Substitution sub, String input)
     {
         return substitute(matcher, pattern, sub, input, 1);



1.15      +14 -14    e/src/jsrc/org/erights/e/develop/trace/Trace.java

Index: Trace.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/develop/trace/Trace.java,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -r1.14 -r1.15
--- Trace.java	2001/09/06 09:55:43	1.14
+++ Trace.java	2001/10/02 23:38:31	1.15
@@ -114,23 +114,23 @@
      *  Predefined subsystems. (tr)
      */
     /** comm systems */
-    static public Trace comm = new Trace("comm");
-    static public Trace captp = new Trace("captp");
-    static public Trace wire = new Trace("wire");
-    static public Trace tunnel = new Trace("tunnel");
+    static public final Trace comm = new Trace("comm");
+    static public final Trace captp = new Trace("captp");
+    static public final Trace wire = new Trace("wire");
+    static public final Trace tunnel = new Trace("tunnel");
     /** Distributed garbage collector. */
-    static public Trace dgc = new Trace("dgc");
-    static public Trace pumpkin = new Trace("pumpkin");
+    static public final Trace dgc = new Trace("dgc");
+    static public final Trace pumpkin = new Trace("pumpkin");
     /** The E runtime */
-    static public Trace eruntime = new Trace("eruntime");
-    static public Trace causality = new Trace("causality");
+    static public final Trace eruntime = new Trace("eruntime");
+    static public final Trace causality = new Trace("causality");
     /** Classes involved in starting up the world. */
-    static public Trace startup = new Trace("startup");
-    static public Trace entropy = new Trace("entropy");
-    static public Trace timers = new Trace("timers");
-    static public Trace trace = new Trace("trace");
+    static public final Trace startup = new Trace("startup");
+    static public final Trace entropy = new Trace("entropy");
+    static public final Trace timers = new Trace("timers");
+    static public final Trace trace = new Trace("trace");
     //misc
-    static public Trace console = new Trace("console");
+    static public final Trace console = new Trace("console");
 
 
     /**
@@ -150,7 +150,7 @@
      * Synchronized static methods are prone to deadlocks in Sun's
      * JVM.  This avoids the problem.
      */
-    static private Object synchronizationObject = new Object();
+    static private final Object synchronizationObject = new Object();
 
 // DEPRECATED FUNCTIONS
 



1.9       +3 -3      e/src/jsrc/org/erights/e/develop/trace/TraceController.java

Index: TraceController.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/develop/trace/TraceController.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- TraceController.java	2001/09/06 09:55:43	1.8
+++ TraceController.java	2001/10/02 23:38:31	1.9
@@ -50,17 +50,17 @@
      * The list of TraceSubsystemMediators for the subsystems being traced.
      * Indexed by subsystem name.
      */
-    static private Hashtable myTraceMediators = new Hashtable();
+    static private final Hashtable myTraceMediators = new Hashtable();
 
     /** Trace thresholds that apply to subsystems that haven't
      *  been given specific values. NUM_ACCEPTORS elements. */
     static private int myDefaultThresholds[];
 
     /** The on-disk log. */
-    static TraceLog myLog;
+    static private TraceLog myLog;
 
     /** Set if stack parsing is to be debugged. */
-    static boolean debugTraceCaller = false;
+    static /*package*/ boolean debugTraceCaller = false;
 
     /**
      * A temporary window into the in-core trace buffer.  Null if no



1.10      +1 -1      e/src/jsrc/org/erights/e/develop/trace/TraceLog.java

Index: TraceLog.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/develop/trace/TraceLog.java,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- TraceLog.java	2001/09/06 09:55:43	1.9
+++ TraceLog.java	2001/10/02 23:38:31	1.10
@@ -84,7 +84,7 @@
     /** This variable is used to count accurately the size of the log.
         Note that I don't try to catch a SecurityException if one occurs.
         We'll have other, bigger, problems if that happens. */
-    static private int lineSeparatorLength =
+    static private final int lineSeparatorLength =
         System.getProperty("line.separator").length();
 
 // QUEUE MANAGEMENT



1.12      +1 -1      e/src/jsrc/org/erights/e/develop/trace/TraceLogDescriptor.java

Index: TraceLogDescriptor.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/develop/trace/TraceLogDescriptor.java,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- TraceLogDescriptor.java	2001/09/06 09:55:43	1.11
+++ TraceLogDescriptor.java	2001/10/02 23:38:31	1.12
@@ -51,7 +51,7 @@
      * The date this trace system was initialized; used as part of the
      * standard name format.
      */
-    static private Date initDate = new Date();
+    static private final Date initDate = new Date();
 
     /** The directory in which the log lives. */
     private File dir = STARTING_LOG_DIR;



1.25      +6 -6      e/src/jsrc/org/erights/e/elib/base/ClassDesc.java

Index: ClassDesc.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/base/ClassDesc.java,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -r1.24 -r1.25
--- ClassDesc.java	2001/10/01 08:31:05	1.24
+++ ClassDesc.java	2001/10/02 23:38:31	1.25
@@ -69,7 +69,7 @@
      * InterfaceGuardSugar by default, and fully unmatched types make use of
      * ClassDesc itself.
      */
-    static private String[][] GuardSugarings = {
+    static private final String[][] GuardSugarings = {
         { "java.lang.Class",
           "org.erights.e.meta.java.lang.ClassGuardSugar" },
         { "java.lang.String",
@@ -119,13 +119,13 @@
     /**
      * The above list of pairs turned into a ConstMap.
      */
-    static private ConstMap TheGuardSugars =
+    static private final ConstMap TheGuardSugars =
         ConstMap.fromPairs(GuardSugarings);
 
     /**
      *
      */
-    static private FlexMap GuardCache =
+    static private final FlexMap GuardCache =
         FlexMap.fromTypes(Class.class, Class.class);
 
     /**
@@ -202,7 +202,7 @@
      * A Mapping from classes, primitive or not, to ClassDescs (instances of
      * ClassDesc or a GuardSugar subclass of ClassDesc).
      */
-    static private FlexMap DescCache =
+    static private final FlexMap DescCache =
         FlexMap.fromTypes(Class.class, ClassDesc.class);
 
     /**
@@ -227,8 +227,8 @@
     static private final Class[] ArgTypes = { Class.class };
 
     /**
-     * Returns a description of the messages that may
-     * be sent to members of this type.
+     * Returns a description of the messages that may be sent to members of
+     * this type.
      */
     static private ClassDesc privateMake(Class clazz)
     throws ClassNotFoundException,



1.2       +1 -1      e/src/jsrc/org/erights/e/elib/prim/BERunner.java

Index: BERunner.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/prim/BERunner.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- BERunner.java	2001/09/14 01:35:22	1.1
+++ BERunner.java	2001/10/02 23:38:31	1.2
@@ -40,7 +40,7 @@
      * The number of Runnables to dequeue and run in one go.
      * Must be >= 1.
      */
-    static private int DEQUEUE_GRANULARITY = 25;
+    static private final int DEQUEUE_GRANULARITY = 25;
 
     /**
      * Note that SynchQueue is a thread-safe data structure with its own lock.



1.2       +1 -1      e/src/jsrc/org/erights/e/elib/prim/SacrificialComponent.java

Index: SacrificialComponent.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/prim/SacrificialComponent.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- SacrificialComponent.java	2001/09/13 00:07:47	1.1
+++ SacrificialComponent.java	2001/10/02 23:38:31	1.2
@@ -35,7 +35,7 @@
     /**
      *
      */
-    static /*package*/ SacrificialComponent THE_ONE =
+    static /*package*/ final SacrificialComponent THE_ONE =
       new SacrificialComponent();
 
     /**



1.37      +2 -2      e/src/jsrc/org/erights/e/elib/prim/ScriptMaker.java

Index: ScriptMaker.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/prim/ScriptMaker.java,v
retrieving revision 1.36
retrieving revision 1.37
diff -u -r1.36 -r1.37
--- ScriptMaker.java	2001/09/06 09:55:48	1.36
+++ ScriptMaker.java	2001/10/02 23:38:31	1.37
@@ -46,7 +46,7 @@
      * This is much like the Simplifications in Equalizer, with some
      * differences.
      */
-    static private String[][] Promotions = {
+    static private final String[][] Promotions = {
         { "java.lang.Byte",     "java.math.BigInteger" },
         { "java.lang.Short",    "java.math.BigInteger" },
         { "java.lang.Integer",  "java.math.BigInteger" },
@@ -95,7 +95,7 @@
      * according to this Java type, but as modified (sugared) by the right
      * hand (value) types.
      */
-    static private String[][] Sugarings = {
+    static private final String[][] Sugarings = {
         { "java.lang.Boolean",
           "org.erights.e.meta.java.lang.BooleanSugar" },
         { "java.lang.Character",



1.20      +2 -2      e/src/jsrc/org/erights/e/elib/prim/StaticMaker.java

Index: StaticMaker.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/prim/StaticMaker.java,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- StaticMaker.java	2001/10/01 08:31:05	1.19
+++ StaticMaker.java	2001/10/02 23:38:31	1.20
@@ -137,7 +137,7 @@
     /**
      *
      */
-    static private String[][] Sugarings = {
+    static private final String[][] Sugarings = {
         { "java.math.BigInteger",
           "org.erights.e.meta.java.math.BigIntegerMakerSugar" }
     };
@@ -152,7 +152,7 @@
     /**
      *
      */
-    static private FlexMap MakerCache =
+    static private final FlexMap MakerCache =
         FlexMap.fromTypes(Class.class, StaticMaker.class);
 
     /**



1.26      +1 -1      e/src/jsrc/org/erights/e/elib/prim/tests/ERunDemo.java

Index: ERunDemo.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/prim/tests/ERunDemo.java,v
retrieving revision 1.25
retrieving revision 1.26
diff -u -r1.25 -r1.26
--- ERunDemo.java	2001/09/10 00:06:52	1.25
+++ ERunDemo.java	2001/10/02 23:38:32	1.26
@@ -66,7 +66,7 @@
 
         Ref i = E.send(s, "indexOf(int)", new Character('o'));
 
-        Ref.whenResolved(i, new OneArgFunc() {
+        Ref.whenResolvedOnly(i, new OneArgFunc() {
             public Object run(Object resolution) {
                 PrintStreamWriter.out().println("near: " + resolution);
                 return null; //to keep the compiler happy



1.7       +1 -1      e/src/jsrc/org/erights/e/elib/ref/DeviceRef.java

Index: DeviceRef.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/ref/DeviceRef.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- DeviceRef.java	2001/09/06 09:55:50	1.6
+++ DeviceRef.java	2001/10/02 23:38:32	1.7
@@ -50,7 +50,7 @@
     private final Runner myTargetsRunner;
     private final Object myTarget;
 
-    static private Object EE = StaticMaker.make(E.class);
+    static private final Object EE = StaticMaker.make(E.class);
 
     /**
      * Make an EVENTUAL reference to target which will queue messages with



1.30      +20 -2     e/src/jsrc/org/erights/e/elib/ref/Ref.java

Index: Ref.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/ref/Ref.java,v
retrieving revision 1.29
retrieving revision 1.30
diff -u -r1.29 -r1.30
--- Ref.java	2001/10/01 08:31:05	1.29
+++ Ref.java	2001/10/02 23:38:32	1.30
@@ -71,8 +71,8 @@
      * The canonical reference BROKEN by TheViciousMarker.  Used to
      * detect vicious forwarding cycles.
      */
-    static /*package*/ final UnconnectedRef TheViciousRef
-        = new UnconnectedRef(ViciousCycleException.TheViciousMarker);
+    static /*package*/ final UnconnectedRef TheViciousRef =
+      new UnconnectedRef(ViciousCycleException.TheViciousMarker);
 
     static /*package*/ final Object[] NO_ARGS = {};
 
@@ -606,6 +606,15 @@
     }
 
     /**
+     * Like {@link #whenResolved(Object, OneArgFunc)} but without a return
+     * result.
+     */
+    static public void whenResolvedOnly(Object ref, OneArgFunc reactor) {
+        E.sendOnly(ref, "whenMoreResolved",
+                   new WhenResolvedReactor(reactor, ref, null));
+    }
+
+    /**
      * Should a breakable reference <i>ever</i> become broken, even if it
      * became fulfilled in the meantime, then the reactor is invoked once
      * with a broken reference.
@@ -631,6 +640,15 @@
                                          ref,
                                          (Resolver)pair[1]));
         return pair[0];
+    }
+
+    /**
+     * Like {@link #whenBroken(Object, OneArgFunc)} but without a return
+     * result.
+     */
+    static public void whenBrokenOnly(Object ref, OneArgFunc reactor) {
+        E.sendOnly(ref, "whenBroken",
+                   new WhenBrokenReactor(reactor, ref, null));
     }
 
 



1.5       +1 -1      e/src/jsrc/org/erights/e/elib/ref/StemCell.java

Index: StemCell.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/ref/StemCell.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- StemCell.java	2001/09/06 09:55:50	1.4
+++ StemCell.java	2001/10/02 23:38:32	1.5
@@ -58,7 +58,7 @@
 public abstract class StemCell extends Ref
 implements PassByConstruction, Persistent {
 
-    static final long serialVersionUID = 3574625250011981396L;
+    static private final long serialVersionUID = 3574625250011981396L;
 
     /**
      * null on the encoding side for a made StemCell.



1.5       +9 -7      e/src/jsrc/org/erights/e/elib/ref/WhenBrokenReactor.java

Index: PassByConstruction.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/serial/PassByConstruction.java,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- PassByConstruction.java	2001/09/23 05:14:48	1.12
+++ PassByConstruction.java	2001/10/02 23:38:32	1.13
@@ -39,20 +39,14 @@
      * and modify them to implement the PassByConstruction interface, but we
      * equally obviously want people to be able to use them as if we had.
      */
-    static final String HONORED_NAMES[] = {
+    static final String[] HONORED_NAMES = {
         //also Transparent & Selfless, and so PassByCopy
         "java.lang.Boolean",
         "java.lang.Character",
         "java.lang.String",
 
         //also Transparent & Selfless, and so PassByCopy
-        "java.lang.Float",
-        "java.lang.Double",
-        "java.lang.Byte",
-        "java.lang.Short",
-        "java.lang.Integer",
-        "java.lang.Long",
-        "java.math.BigInteger",
+        "java.lang.Number",
 
         //also Selfless, but not Transparent or PassByCopy
         "net.captp.api.SturdyRef",



1.6       +1 -1      e/src/jsrc/org/erights/e/elib/serial/PassByProxy.java

Index: PassByProxy.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/serial/PassByProxy.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- PassByProxy.java	2001/09/06 09:55:51	1.5
+++ PassByProxy.java	2001/10/02 23:38:32	1.6
@@ -40,7 +40,7 @@
      * modify them to implement the PassByProxy interface, but we equally
      * obviously want people to be able to use them as if we had. <p>
      */
-    static final String HONORED_NAMES[] = {
+    static final String[] HONORED_NAMES = {
         "java.io.File",
         "java.net.URL",
         "java.rmi.Remote",



1.6       +2 -8      e/src/jsrc/org/erights/e/elib/serial/Persistent.java

Index: Persistent.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/serial/Persistent.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- Persistent.java	2001/09/23 05:14:48	1.5
+++ Persistent.java	2001/10/02 23:38:32	1.6
@@ -41,20 +41,14 @@
      * and modify them to implement the Persistent interface, but we equally
      * obviously want people to be able to use them as if we had.
      */
-    static final String HONORED_NAMES[] = {
+    static final String[] HONORED_NAMES = {
         //also PBC, Transparent, & Selfless, and so PassByCopy
         "java.lang.Boolean",
         "java.lang.Character",
         "java.lang.String",
 
         //also PBC, Transparent, & Selfless, and so PassByCopy
-        "java.lang.Float",
-        "java.lang.Double",
-        "java.lang.Byte",
-        "java.lang.Short",
-        "java.lang.Integer",
-        "java.lang.Long",
-        "java.math.BigInteger",
+        "java.lang.Number",
 
         //also PBC & Selfless, but not Transparent or PassByCopy
         "net.captp.api.SturdyRef",



1.5       +1 -1      e/src/jsrc/org/erights/e/elib/serial/RemoteCall.java

Index: RemoteCall.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/serial/RemoteCall.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- RemoteCall.java	2001/09/07 05:49:23	1.4
+++ RemoteCall.java	2001/10/02 23:38:32	1.5
@@ -48,7 +48,7 @@
  */
 public class RemoteCall extends StemCell {
 
-    static final long serialVersionUID = 3703520454697636174L;
+    static private final long serialVersionUID = 3703520454697636174L;
 
     /** @serial receives the message */
     private Object myRecipient;



1.8       +1 -1      e/src/jsrc/org/erights/e/elib/serial/RemoteDelivery.java

Index: RemoteDelivery.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/serial/RemoteDelivery.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- RemoteDelivery.java	2001/09/07 05:49:23	1.7
+++ RemoteDelivery.java	2001/10/02 23:38:32	1.8
@@ -41,7 +41,7 @@
  */
 public class RemoteDelivery extends StemCell {
 
-    static final long serialVersionUID = -1702614205914869122L;
+    static private final long serialVersionUID = -1702614205914869122L;
 
     /** @serial receives the message */
     private Object myRecipient;



1.25      +1 -1      e/src/jsrc/org/erights/e/elib/tables/ConstMap.java

Index: ConstMap.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/tables/ConstMap.java,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -r1.24 -r1.25
--- ConstMap.java	2001/09/07 05:49:23	1.24
+++ ConstMap.java	2001/10/02 23:38:32	1.25
@@ -46,7 +46,7 @@
 public abstract class ConstMap
 extends EMap implements Selfless, PassByConstruction {
 
-    static final long serialVersionUID = -6424210992869387563L;
+    static private final long serialVersionUID = -6424210992869387563L;
 
     /**
      *



1.18      +1 -1      e/src/jsrc/org/erights/e/elib/tables/ConstMapImpl.java

Index: ConstMapImpl.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/tables/ConstMapImpl.java,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- ConstMapImpl.java	2001/09/06 09:55:51	1.17
+++ ConstMapImpl.java	2001/10/02 23:38:32	1.18
@@ -30,7 +30,7 @@
  */
 /*package*/ class ConstMapImpl extends ConstMap {
 
-    static final long serialVersionUID = -2814488931279192860L;
+    static private final long serialVersionUID = -2814488931279192860L;
 
     /**
      * This class should never be directly unserialized, so this instance



1.27      +1 -1      e/src/jsrc/org/erights/e/elib/tables/EMap.java

Index: EMap.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/tables/EMap.java,v
retrieving revision 1.26
retrieving revision 1.27
diff -u -r1.26 -r1.27
--- EMap.java	2001/09/07 05:49:23	1.26
+++ EMap.java	2001/10/02 23:38:32	1.27
@@ -64,7 +64,7 @@
  */
 public abstract class EMap implements EPrintable, Persistent {
 
-    static final long serialVersionUID = -7066420784218105992L;
+    static private final long serialVersionUID = -7066420784218105992L;
 
     /**
      * This object must never be stored as a value in a map.  It's used as an



1.4       +3 -3      e/src/jsrc/org/erights/e/elib/tables/EmptyTwine.java

Index: EmptyTwine.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/tables/EmptyTwine.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- EmptyTwine.java	2001/09/07 05:49:23	1.3
+++ EmptyTwine.java	2001/10/02 23:38:32	1.4
@@ -39,13 +39,13 @@
     /**
      * The canonical instance
      */
-    static /*package*/ Twine THE_ONE = new EmptyTwine();
+    static /*package*/ final Twine THE_ONE = new EmptyTwine();
 
     /**
      *
      */
-    static private Object[] CanonicalState =
-            { TwineMaker, "fromString", "" };
+    static private final Object[] CanonicalState =
+      { TwineMaker, "fromString", "" };
 
     /**
      *



1.26      +1 -1      e/src/jsrc/org/erights/e/elib/tables/Equalizer.java

Index: Equalizer.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/tables/Equalizer.java,v
retrieving revision 1.25
retrieving revision 1.26
diff -u -r1.25 -r1.26
--- Equalizer.java	2001/09/06 09:55:51	1.25
+++ Equalizer.java	2001/10/02 23:38:32	1.26
@@ -36,7 +36,7 @@
      * This is much like the Promotions in ScriptMaker, with some
      * differences.
      */
-    static private String[][] Simplifications = {
+    static private final String[][] Simplifications = {
         { "java.lang.Byte",                         "java.math.BigInteger" },
         { "java.lang.Short",                        "java.math.BigInteger" },
         { "java.lang.Integer",                      "java.math.BigInteger" },



1.14      +1 -1      e/src/jsrc/org/erights/e/elib/tables/KeyColumn.java

Index: KeyColumn.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/tables/KeyColumn.java,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -r1.13 -r1.14
--- KeyColumn.java	2001/09/06 09:55:51	1.13
+++ KeyColumn.java	2001/10/02 23:38:32	1.14
@@ -90,7 +90,7 @@
      * Little sorted array of primes for use to size key columns.
      * The elements grow exponentially at somewhat less than 2x.
      */
-    static final private int possibleSizes[] = {
+    static private final int possibleSizes[] = {
       17, 23, 37, 53, 79, 109, 151, 211, 293, 421, 593, 829, 1171, 1637, 2293,
       3209, 4493, 6299, 8819, 12347, 17257, 24197, 33871, 47431, 66403,
       92959, 130147, 182209, 255107, 357139, 500009, 700027, 980047, 1372051,



1.11      +3 -10     e/src/jsrc/org/erights/e/elib/tables/Selfless.java

Index: Selfless.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/tables/Selfless.java,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- Selfless.java	2001/09/06 09:55:51	1.10
+++ Selfless.java	2001/10/02 23:38:32	1.11
@@ -84,20 +84,14 @@
      * and modify them to implement the Selfless interface, but we also
      * obviously want people to be able to use them as if we had.
      */
-    static final String HONORED_NAMES[] = {
+    static final String[] HONORED_NAMES = {
         //also Transparent & PassByConstruction, and so PassByCopy
         "java.lang.Boolean",
         "java.lang.Character",
         "java.lang.String",
 
         //also Transparent & PassByConstruction, and so PassByCopy
-        "java.lang.Float",
-        "java.lang.Double",
-        "java.lang.Byte",
-        "java.lang.Short",
-        "java.lang.Integer",
-        "java.lang.Long",
-        "java.math.BigInteger",
+        "java.lang.Number",
 
         //also Transparent & PassByConstruction, and so PassByCopy
         //made HONORARY for speed, and so it can be used as a FarRef identity.
@@ -112,7 +106,6 @@
         //Not really Selfless, but does its own sameness
         "org.erights.e.elib.tables.WeakKey",
 
-
         //Not Near, and therefore not actually Selfless, but does its own
         //sameness comparison.
         //also PassByConstruction, but not Transparent or PassByCopy
@@ -127,6 +120,6 @@
      * HONORARY (effectively) contains all the classes named in HONORED_NAMES
      * and all their subclasses.
      */
-    static final ConstSubclassSet HONORARY
+    static public final ConstSubclassSet HONORARY
         = ConstSubclassSet.make(HONORED_NAMES);
 }



1.18      +1 -1      e/src/jsrc/org/erights/e/extern/timer/Timer.java

Index: Timer.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/extern/timer/Timer.java,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -r1.17 -r1.18
--- Timer.java	2001/09/07 05:49:24	1.17
+++ Timer.java	2001/10/02 23:38:32	1.18
@@ -48,7 +48,7 @@
     static private final Object[] NO_ARGS = {};
 
     /** The single permitted instance of this class */
-    static private Timer TheTimer = new Timer();
+    static private final Timer TheTimer = new Timer();
 
     /** Our timer thread */
     private TimerThread myThread = null;



1.8       +2 -1      e/src/jsrc/org/erights/e/meta/java/lang/ArrayGuardSugar.java

Index: ArrayGuardSugar.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/meta/java/lang/ArrayGuardSugar.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- ArrayGuardSugar.java	2001/09/06 09:55:55	1.7
+++ ArrayGuardSugar.java	2001/10/02 23:38:32	1.8
@@ -29,7 +29,8 @@
 import java.lang.reflect.Array;
 
 /**
- *
+ * Coerces arrays and ConstLists to the type 'T[]' (array of T), for some type
+ * T, by coercing each element to T.
  *
  * @author <a href="mailto:markm@erights.org">Mark S. Miller</a>
  */



1.10      +3 -16     e/src/jsrc/org/erights/e/meta/java/lang/InterfaceGuardSugar.java

Index: InterfaceGuardSugar.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/meta/java/lang/InterfaceGuardSugar.java,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- InterfaceGuardSugar.java	2001/09/07 05:49:24	1.9
+++ InterfaceGuardSugar.java	2001/10/02 23:38:32	1.10
@@ -27,26 +27,13 @@
 import org.erights.e.elib.util.OneArgFunc;
 
 /**
+ * {@link Callable}s (eg, objects defined in the E language) coerce to
+ * interfaces by deflection.
  *
- *
+ * @see Deflector
  * @author <a href="mailto:markm@erights.org">Mark S. Miller</a>
  */
 public class InterfaceGuardSugar extends ClassDesc {
-
-    /**
-     *
-     */
-    static private Class DeflectorClass = null;
-
-    /**
-     *
-     */
-    static private boolean DeflectorBad = false;
-
-    /**
-     *
-     */
-    static private final Class[] ArgTypes = { Callable.class };
 
     /**
      * @param clazz must represent an interface type



1.10      +1 -1      e/src/jsrc/org/erights/e/ui/jed/EAction.java

Index: EAction.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/ui/jed/EAction.java,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- EAction.java	2001/09/23 10:46:16	1.9
+++ EAction.java	2001/10/02 23:38:32	1.10
@@ -66,7 +66,7 @@
     /**
      *
      */
-    static private IntTable ModNames = new IntTable(String.class);
+    static private final IntTable ModNames = new IntTable(String.class);
 
     static {
         ModNames.putInt("SHIFT", Event.SHIFT_MASK);



1.15      +1 -1      e/src/jsrc/org/erights/e/ui/jed/EMenuBar.java

Index: EMenuBar.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/ui/jed/EMenuBar.java,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -r1.14 -r1.15
--- EMenuBar.java	2001/09/06 18:01:32	1.14
+++ EMenuBar.java	2001/10/02 23:38:32	1.15
@@ -67,7 +67,7 @@
     /**
      *
      */
-    static private IntTable ModNames = new IntTable(String.class);
+    static private final IntTable ModNames = new IntTable(String.class);
 
     static {
         ModNames.putInt("SHIFT", Event.SHIFT_MASK);
Index: WhenBrokenReactor.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/ref/WhenBrokenReactor.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- WhenBrokenReactor.java	2001/09/06 09:55:50	1.4
+++ WhenBrokenReactor.java	2001/10/02 23:38:32	1.5
@@ -53,19 +53,19 @@
     private Resolver myOptResolver;
 
     /**
      * Should ref become broken, invoke wrapped, and resolve resolver to its
      * outcome.
      * <p>
      * Assumes a first whenBroken will be sent with this WhenBrokenReactor as
      * argument.
      */
     public WhenBrokenReactor(OneArgFunc wrapped,
                              Object ref,
-                             Resolver resolver)
+                             Resolver optResolver)
     {
         myOptWrapped = wrapped;
         myRef = ref;
-        myOptResolver = resolver;
+        myOptResolver = optResolver;
     }
 
     /**
@@ -93,14 +93,16 @@
         if (Ref.isBroken(myRef)) {
             Object ref = myRef;
             OneArgFunc wrapped = myOptWrapped;
-            Resolver resolver = myOptResolver;
+            Resolver optResolver = myOptResolver;
 
             myRef = null;
             myOptWrapped = null;
             myOptResolver = null;
 
-            resolver.resolve(E.send(wrapped, "run", ref));
-
+            Ref outcome = E.send(wrapped, "run", ref);
+            if (null != optResolver) {
+                optResolver.resolve(outcome);
+            }
         } else if (Ref.isNear(myRef)) {
             // Once it's near, it'll never be broken.
             // Note that the resolver will be forever unresolved in this
@@ -53,19 +53,19 @@
 
     /**
-     * Should ref become broken, invoke wrapped, and resolve resolver to its
-     * outcome.
+     * Should ref become broken, invoke wrapped, and resolve optResolver (if
+     * not null) to its outcome.
      * <p>
      * Assumes a first whenBroken will be sent with this WhenBrokenReactor as



1.11      +9 -7      e/src/jsrc/org/erights/e/elib/ref/WhenResolvedReactor.java

Index: WhenResolvedReactor.java
===================================================================
RCS file: /cvs/e/src/jsrc/org/erights/e/elib/ref/WhenResolvedReactor.java,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- WhenResolvedReactor.java	2001/09/06 09:55:50	1.10
+++ WhenResolvedReactor.java	2001/10/02 23:38:32	1.11
@@ -59,19 +59,19 @@
     private Resolver myOptResolver;
 
     /**
      * When ref is resolved, invoke wrapped, and resolve resolver to its
      * outcome.
      * <p>
      * Assumes a first whenMoreResolved will be sent with this
      * WhenResolvedReactor as argument.
      */
     /*package*/ WhenResolvedReactor(OneArgFunc wrapped,
                                     Object ref,
-                                    Resolver resolver)
+                                    Resolver optResolver)
     {
         myOptWrapped = wrapped;
         myRef = ref;
-        myOptResolver = resolver;
+        myOptResolver = optResolver;
     }
 
     /**
@@ -98,14 +98,16 @@
         if (Ref.isResolved(myRef)) {
             Object ref = myRef;
             OneArgFunc wrapped = myOptWrapped;
-            Resolver resolver = myOptResolver;
+            Resolver optResolver = myOptResolver;
 
             myRef = null;
             myOptWrapped = null;
             myOptResolver = null;
 
-            resolver.resolve(E.send(wrapped, "run", ref));
-
+            Ref outcome = E.send(wrapped, "run", ref);
+            if (null != optResolver) {
+                optResolver.resolve(outcome);
+            }
         } else {
             //Not yet resolved, keep polling.
             E.sendOnly(myRef, "whenMoreResolved", this);
@@ -59,19 +59,19 @@
 
     /**
-     * When ref is resolved, invoke wrapped, and resolve resolver to its
-     * outcome.
+     * When ref is resolved, invoke wrapped, and resolve optResolver (if
+     * non-null) to its outcome.
      * <p>
      * Assumes a first whenMoreResolved will be sent with this



1.13      +2 -8      e/src/jsrc/org/erights/e/elib/serial/PassByConstruction.java
